package com.zj365.mime.act

import android.view.View
import android.widget.ImageView
import androidx.core.content.ContextCompat
import com.alibaba.android.arouter.facade.annotation.Route
import com.xty.base.act.BaseVmAct
import com.xty.common.bracelet.YCBBlueConnectHelper
import com.xty.common.Const
import com.xty.common.MMkvHelper
import com.xty.common.arouter.ARouterUrl
import com.xty.common.event.BlueToothConnectEvent
import com.xty.common.event.MyInfoEvent
import com.zj365.mime.R
import com.zj365.mime.databinding.ActDevInfoBinding
import com.zj365.mime.vm.SettingVm
import com.zj365.mime.weight.FactorySettingDialog
import com.xty.network.MyRetrofit
import com.xty.network.model.SettingBean
import org.greenrobot.eventbus.EventBus

/**
 * 设备解绑 设备信息
 */
@Route(path = ARouterUrl.DEV_INFO)
class DevInfoAct : BaseVmAct<SettingVm>() {

    val binding by lazy { ActDevInfoBinding.inflate(layoutInflater) }
    override fun setLayout() = binding.root

    var user: SettingBean.User? = null
    var userId: String? = null
    private val unBindDialog by lazy {
        FactorySettingDialog(this, getString(R.string.dialog_un_bind)) {
            //确认解除绑定
            mViewModel.unBind()
        }
    }

    override fun initData() {
        super.initData()
        isDarkBar = true
        val userBean = intent.getSerializableExtra("user")
        if (userBean != null) {
            user = userBean as SettingBean.User
        }
        userId = intent.getStringExtra("userId")
    }

    override fun initView() {
        super.initView()
        statusBar(binding.title.mView)
        binding.title.mIvBack.setOnClickListener { finish() }
        binding.title.mTvTitle.text = "设备信息"
        binding.title.mTvRight.apply {
            if (user != null) {
                visibility = View.VISIBLE
            } else {
                visibility = View.GONE
            }
            text = "解除绑定"
            setTextColor(ContextCompat.getColor(this@DevInfoAct, R.color.col_02c))
            setOnClickListener {
                unBindDialog.showDialog()
            }
        }
        user?.let {
            binding.mNickName.text = "设备名称：${it.watchName}"
            binding.mNum.text = "设备地址：${it.bluetooth}"
            binding.mCode.text = "设备编号：${it.deviceId}"
            binding.mActiveCode.text = "设备激活码：${it.activationCode}"
            binding.mActiveCode.visibility = View.VISIBLE
            setDevicePic(it.deviceType, binding.ivDevice)
        }

        userId?.let {
            mViewModel.getUserDeviceInfo(userId!!)
        }
    }

    override fun liveObserver() {
        mViewModel.unbindLive.observe(this) {
            user!!.bluetooth = ""
            Const.mainLiveData.value!!.user.bluetooth = ""//将蓝牙信息清空
            MyRetrofit.get().BLUETOOTH_MAC = ""//清除蓝牙信息
            MMkvHelper.remove(Const.Watch_Device_Type)//清除手表型号
            Const.watchType = -1//将手表型号恢复初始值
            Const.battery = ""//电池信息恢复初始值
            MMkvHelper.remove(Const.Blue_Tooth)//清除蓝牙信息
            YCBBlueConnectHelper.disconnect()
            YCBBlueConnectHelper.cancelTimer()
            MMkvHelper.clearWhatchInfo()//删除手表信息
            EventBus.getDefault().post(BlueToothConnectEvent())//刷新蓝牙连接信息
            EventBus.getDefault().post(MyInfoEvent())  //刷新个人信息
            finish()
        }

        mViewModel.deviceInfo.observe(this) {

            binding.mNickName.text = "设备名称：${it.data.watchName?:""}"
            binding.mNum.text = "设备地址：${it.data.bluetooth?:""}"
            binding.mCode.text = "设备编号：${it.data.deviceCode?:""}"
            binding.mActiveCode.text = "设备激活码：${it.data.activationCode?:""}"
            binding.mActiveCode.visibility = View.VISIBLE

            setDevicePic(it.data.deviceType, binding.ivDevice)
        }
    }


    private fun setDevicePic(type: String?, imageView: ImageView) {
        if (type == null) {
            return
        }
        when (type) {
            "U32" -> {
                imageView.setImageResource(R.mipmap.ic_watch_u32_big)
            }

            "A3" -> {
                imageView.setImageResource(R.mipmap.ic_watch_a3_big)
            }

            "X1" -> {
                imageView.setImageResource(R.mipmap.ic_watch_x1_big)
            }

            "X2" -> {
                imageView.setImageResource(R.mipmap.ic_watch_x2_big)
            }
        }
    }

}